This Project is Forked From [MineTorch](https://github.com/louis-she/minetorch).

Published on [pypi](https://pypi.org/project/torchminer/)

Packaged Using [Poetry](https://python-poetry.org/)

# Description
TorchMiner is designed to automatic process the training ,evaluating and testing process for PyTorch DeepLearning,with a simple API.

You can access all Functions of MineTorch simply use `Miner`.
